# $Id: autodoc.make,v 1.8 1999/10/07 19:05:19 aswift Exp $
#
# autodoc.make
#
# Rules for installing public documentation.
#
# PUBLIC TARGETS
#     build-public-documentation:  Use this to build and install autodoc
#        documentation into the AUTODOC_DOCDIR, which is defined in
#        common.make.preamble.  AUTODOC_DOCDIR will be set to either
#        PUBLIC_DOC_BUILDDIR or DSTROOT/PUBLIC_DOC_INSTALLDIR depending
#        on the build style chosen.
#
# IMPORTED VARIABLES
#     OTHER_PUBLIC_DOCUMENTATION:  documentation (.rtf or .html) files which 
#     should be installed/copied into the public documentation location
#     PUBLIC_DOC_INSTALLDIR:  the directory into which public documentation 
#     should be installed.
#     PUBLIC_DOC_BUILDDIR:  the directory into which public documentation 
#     should be built.
#     AUTODOC_FORMATS:  the formats to build documentation into (rtf and/or html)
#     OTHER_AUTODOC_FLAGS:  additional project specific autodoc flags
#     AUTODOC_LANGUAGE:  the language-specific resource destination directory
#     AUTODOC_DOCDIR: set by common.make.preamble
#

.PHONY: build-public-documentation announce-install-documentation announce-build-documentation

#
# autodoc execution configuration stuff
#
AUTODOC = /usr/local/bin/autodoc
AUTODOC_FLAGS = -copydocs -timestamp -allclasses

#
# configuring the documentation formats (default = rtf)
#
ifndef AUTODOC_FORMATS
    AUTODOC_FORMATS = rtf
endif

#
# configuring the language for the documentation resource directory
#
ifndef AUTODOC_LANGUAGE
    ifdef LANGUAGE
        AUTODOC_LANGUAGE = $(LANGUAGE)
    else
        AUTODOC_LANGUAGE = English
    endif
endif

#
# announcing documentation construction
#
announce-install-documentation:
ifndef RECURSING
	$(SILENT) $(ECHO) Installing documentation...
else
	$(SILENT) $(ECHO) $(RECURSIVE_ELLIPSIS)installing documentation from $(NAME)
endif

announce-build-documentation:
ifndef RECURSING
	$(SILENT) $(ECHO) Building documentation...
endif


#
# Installing the documentation to AUTODOC_DOCDIR
#
ALL_AUTODOC_FLAGS = $(AUTODOC_FLAGS) $(OTHER_AUTODOC_FLAGS)
ALL_AUTODOC_FILES = $(PUBLIC_HEADERS) $(OTHER_PUBLIC_HEADERS) $(OTHER_PUBLIC_DOCUMENTATION)

build-public-documentation: $(AUTODOC_DOCDIR) $(ALL_AUTODOC_FILES)
ifneq "" "$(strip $(ALL_AUTODOC_FILES))"
    ifneq "" "$(strip $(AUTODOC_DOCDIR))"
		-$(SILENT) $(foreach FORMAT, $(AUTODOC_FORMATS), \
			$(AUTODOC) $(ALL_AUTODOC_FLAGS) -format $(FORMAT) \
				-dest $(AUTODOC_DOCDIR) $(ALL_AUTODOC_FILES);)
    else
		$(SILENT) $(ECHO) Must set a public documentation directory to install documentation.
		exit 1
    endif
endif


#
# Creating necessary directories (if needed)
#
$(DSTROOT)$(PUBLIC_DOC_INSTALLDIR) $(PUBLIC_DOC_BUILDDIR):
	$(MKDIRS) $@

